@@ -1,7 +1,7 @@
-from typing import Union
+from typing import Union, List
 from google.cloud.exceptions import GoogleCloudError
 from botrun_flow_lang.constants import USER_SETTING_STORE_NAME
-from botrun_flow_lang.services.user_setting.user_setting import UserSetting
+from botrun_hatch.models.user_setting import UserSetting
 from botrun_flow_lang.services.base.firestore_base import FirestoreBase
 
 
@@ -36,3 +36,31 @@ class UserSettingFsStore(FirestoreBase):
         except GoogleCloudError as e:
             print(f"Error deleting user setting for {user_id}: {e}")
             return False
+
+    async def get_all_user_ids(self) -> List[str]:
+        """Get all user IDs (document IDs) from the collection.
+
+        Returns:
+            List[str]: List of all user IDs
+        """
+        try:
+            all_user_ids = []
+            # Get first batch
+            query = self.collection.limit(20)
+            while True:
+                docs = list(query.stream())
+                if not docs:
+                    break
+
+                # Add document IDs from current batch
+                all_user_ids.extend([doc.id for doc in docs])
+
+                # Get last document from current batch
+                last_doc = docs[-1]
+                # Update query to start after the last document
+                query = self.collection.limit(20).start_after(last_doc)
+
+            return all_user_ids
+        except GoogleCloudError as e:
+            print(f"Error getting all user IDs: {e}")
+            return []
